==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/TopoSorter.h <==
// public class soot.jimple.spark.solver.TopoSorter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 29fe8b63e0e9be9a soot_jimple_spark_solver_TopoSorter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_solver_TopoSorter_H_
#define _JC_soot_jimple_spark_solver_TopoSorter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$sub_refs	_jc_soot_jimple_spark_solver_TopoSorter$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$sub_nonrefs	_jc_soot_jimple_spark_solver_TopoSorter$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$refs	_jc_soot_jimple_spark_solver_TopoSorter$refs;
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$nonrefs	_jc_soot_jimple_spark_solver_TopoSorter$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$object	_jc_soot_jimple_spark_solver_TopoSorter$object;

typedef const struct _jc_soot_jimple_spark_solver_TopoSorter$vmethods	_jc_soot_jimple_spark_solver_TopoSorter$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_TopoSorter$vtable	_jc_soot_jimple_spark_solver_TopoSorter$vtable;
typedef const struct _jc_soot_jimple_spark_solver_TopoSorter$vtype	_jc_soot_jimple_spark_solver_TopoSorter$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_TopoSorter$method$_init$f122f46e77bbb54d(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *, struct _jc_soot_jimple_spark_pag_PAG$object *, jboolean);

// Virtual methods
extern void _jc_soot_jimple_spark_solver_TopoSorter$method$dfsVisit$61223eddaae88bd8(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
extern void _jc_soot_jimple_spark_solver_TopoSorter$method$sort$7beff0d238c081ee(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_TopoSorter$method_info$dfsVisit$61223eddaae88bd8;
extern _jc_method _jc_soot_jimple_spark_solver_TopoSorter$method_info$sort$7beff0d238c081ee;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_TopoSorter$vmethods {
	void	(*dfsVisit$61223eddaae88bd8)(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
	void	(*sort$7beff0d238c081ee)(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_TopoSorter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_TopoSorter$vmethods	soot_jimple_spark_solver_TopoSorter;
};

// Vtype
struct _jc_soot_jimple_spark_solver_TopoSorter$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_TopoSorter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_TopoSorter$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_java_util_HashSet$object	*visited;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_TopoSorter$refs {
    _jc_soot_jimple_spark_solver_TopoSorter$sub_refs	soot_jimple_spark_solver_TopoSorter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_TopoSorter$sub_nonrefs {
	jboolean	ignoreTypes;
	jint	nextFinishNumber;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_TopoSorter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_TopoSorter$sub_nonrefs	soot_jimple_spark_solver_TopoSorter;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_TopoSorter$object {
	_jc_soot_jimple_spark_solver_TopoSorter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_TopoSorter$vtype	*vtype;
	_jc_soot_jimple_spark_solver_TopoSorter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_TopoSorter$vtype _jc_soot_jimple_spark_solver_TopoSorter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_TopoSorter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_TopoSorter$class_object;

#endif	/* _JC_soot_jimple_spark_solver_TopoSorter_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/TopoSorter.h <==
// public class soot.jimple.spark.solver.TopoSorter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 29fe8b63e0e9be9a soot_jimple_spark_solver_TopoSorter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_solver_TopoSorter_H_
#define _JC_soot_jimple_spark_solver_TopoSorter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$sub_refs	_jc_soot_jimple_spark_solver_TopoSorter$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$sub_nonrefs	_jc_soot_jimple_spark_solver_TopoSorter$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$refs	_jc_soot_jimple_spark_solver_TopoSorter$refs;
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$nonrefs	_jc_soot_jimple_spark_solver_TopoSorter$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_TopoSorter$object	_jc_soot_jimple_spark_solver_TopoSorter$object;

typedef const struct _jc_soot_jimple_spark_solver_TopoSorter$vmethods	_jc_soot_jimple_spark_solver_TopoSorter$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_TopoSorter$vtable	_jc_soot_jimple_spark_solver_TopoSorter$vtable;
typedef const struct _jc_soot_jimple_spark_solver_TopoSorter$vtype	_jc_soot_jimple_spark_solver_TopoSorter$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_TopoSorter$method$_init$f122f46e77bbb54d(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *, struct _jc_soot_jimple_spark_pag_PAG$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_solver_TopoSorter$method$dfsVisit$61223eddaae88bd8(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_TopoSorter$method$sort$7beff0d238c081ee(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_TopoSorter$method_info$dfsVisit$61223eddaae88bd8;
extern _jc_method _jc_soot_jimple_spark_solver_TopoSorter$method_info$sort$7beff0d238c081ee;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_TopoSorter$vmethods {
	void	(*dfsVisit$61223eddaae88bd8)(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
	void	(*sort$7beff0d238c081ee)(_jc_env *, struct _jc_soot_jimple_spark_solver_TopoSorter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_TopoSorter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_TopoSorter$vmethods	soot_jimple_spark_solver_TopoSorter;
};

// Vtype
struct _jc_soot_jimple_spark_solver_TopoSorter$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_TopoSorter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_TopoSorter$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_java_util_HashSet$object	*visited;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_TopoSorter$refs {
    _jc_soot_jimple_spark_solver_TopoSorter$sub_refs	soot_jimple_spark_solver_TopoSorter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_TopoSorter$sub_nonrefs {
	jboolean	ignoreTypes;
	jint	nextFinishNumber;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_TopoSorter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_TopoSorter$sub_nonrefs	soot_jimple_spark_solver_TopoSorter;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_TopoSorter$object {
	_jc_soot_jimple_spark_solver_TopoSorter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_TopoSorter$vtype	*vtype;
	_jc_soot_jimple_spark_solver_TopoSorter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_TopoSorter$vtype _jc_soot_jimple_spark_solver_TopoSorter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_TopoSorter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_TopoSorter$class_object;

#endif	/* _JC_soot_jimple_spark_solver_TopoSorter_H_ */
